Pluggable mechanism
===================

Savanna Pluggable Provisioning Mechanism aims to deploy Hadoop clusters and integrate them with 3rd party vendor
management tools like Cloudera Management Console, Hortonworks Ambari, Intel Hadoop Distribution and monitoring tools
like NagiOS, Zabbix, Ganglia.

`Read full specification here <https://wiki.openstack.org/wiki/Savanna/PluggableProvisioning>`_.


.. note::

    Object model, flow and detailed description will be moved here once this functionality is checked into repository.